@@ -86,7 +86,7 @@
 #define KPACKAGE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KPACKAGE_NO_DEPRECATED
-#  define KPACKAGE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55400
+#  define KPACKAGE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55700
 #endif
 #ifdef KPACKAGE_NO_DEPRECATED_WARNINGS
 #  define KPACKAGE_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KPACKAGE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KPACKAGE_DEPRECATED_WARNINGS_SINCE KPACKAGE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KPACKAGE_DEPRECATED_WARNINGS_SINCE 0x55400
+#    define KPACKAGE_DEPRECATED_WARNINGS_SINCE 0x55700
 #  endif
 #endif
 
@@ -121,6 +121,18 @@
 #else
 #  define KPACKAGE_DEPRECATED_VERSION_5_84(text)
 #endif
+
+#if KPACKAGE_DEPRECATED_WARNINGS_SINCE >= 0x55500
+#  define KPACKAGE_DEPRECATED_VERSION_5_85(text) KPACKAGE_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KPACKAGE_DEPRECATED_VERSION_5_85(text)
+#endif
+
+#if KPACKAGE_DEPRECATED_WARNINGS_SINCE >= 0x55600
+#  define KPACKAGE_DEPRECATED_VERSION_5_86(text) KPACKAGE_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KPACKAGE_DEPRECATED_VERSION_5_86(text)
+#endif
 #define KPACKAGE_DEPRECATED_VERSION_5(minor, text)      KPACKAGE_DEPRECATED_VERSION_5_##minor(text)
 #define KPACKAGE_DEPRECATED_VERSION(major, minor, text) KPACKAGE_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KPACKAGE_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KPACKAGE_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
@@ -186,7 +198,7 @@
 #define KPACKAGE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KPACKAGE_NO_DEPRECATED
-#  define KPACKAGE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55400
+#  define KPACKAGE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55700
 #endif
 #ifdef KPACKAGE_NO_DEPRECATED_WARNINGS
 #  define KPACKAGE_DEPRECATED_WARNINGS_SINCE 0
@@ -196,7 +208,7 @@
 #  ifdef KPACKAGE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KPACKAGE_DEPRECATED_WARNINGS_SINCE KPACKAGE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KPACKAGE_DEPRECATED_WARNINGS_SINCE 0x55400
+#    define KPACKAGE_DEPRECATED_WARNINGS_SINCE 0x55700
 #  endif
 #endif
 
@@ -221,6 +233,18 @@
 #else
 #  define KPACKAGE_DEPRECATED_VERSION_5_84(text)
 #endif
+
+#if KPACKAGE_DEPRECATED_WARNINGS_SINCE >= 0x55500
+#  define KPACKAGE_DEPRECATED_VERSION_5_85(text) KPACKAGE_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KPACKAGE_DEPRECATED_VERSION_5_85(text)
+#endif
+
+#if KPACKAGE_DEPRECATED_WARNINGS_SINCE >= 0x55600
+#  define KPACKAGE_DEPRECATED_VERSION_5_86(text) KPACKAGE_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KPACKAGE_DEPRECATED_VERSION_5_86(text)
+#endif
 #define KPACKAGE_DEPRECATED_VERSION_5(minor, text)      KPACKAGE_DEPRECATED_VERSION_5_##minor(text)
 #define KPACKAGE_DEPRECATED_VERSION(major, minor, text) KPACKAGE_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KPACKAGE_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KPACKAGE_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
